@@ -9,9 +9,7 @@ import sys
 import sphinx_py3doc_enhanced_theme
 
 
-mock_modules = [
-    'matplotlib',
-    ]
+mock_modules = []
 
 for modulename in mock_modules:
     sys.modules[modulename] = mock.Mock()
@@ -44,17 +42,17 @@ if os.getenv('SPELLCHECK'):
 
 source_suffix = '.rst'
 master_doc = 'index'
-project = 'Python-Project-Skeleton'
-year = '2020'
-author = 'Joao MC Teixeira'
+project = 'parallel_write'
+year = '2021'
+author = 'NAGY, Attila'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '0.0.7'
+version = release = '0.0.8'
 
 pygments_style = 'trac'
 templates_path = ['.']
 extlinks = {
-    'issue': ('https://github.com/bra-fsn/python-project-skeleton/issues/%s', '#'),  # noqa: E501
-    'pr': ('https://github.com/bra-fsn/python-project-skeleton/pull/%s', 'PR #'),  # noqa: E501
+    'issue': ('https://github.com/Mikata-Project/parallel_write/issues/%s', '#'),  # noqa: E501
+    'pr': ('https://github.com/Mikata-Project/parallel_write/pull/%s', 'PR #'),  # noqa: E501
     }
 
 # codecov io closes connection if host is accessed too repetitively.
@@ -62,13 +60,13 @@ extlinks = {
 # in the .travis.yml file
 # see https://github.com/codecov/codecov-python/issues/158
 linkcheck_ignore = [
-    r'https://codecov.io/gh/bra-fsn/python-project-skeleton/*',
+    r'https://app.codecov.io/gh/Mikata-Project/parallel_write/*',
     ]
 
 html_theme = "sphinx_py3doc_enhanced_theme"
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
 html_theme_options = {
-    'githuburl': 'https://github.com/bra-fsn/python-project-skeleton',
+    'githuburl': 'https://github.com/Mikata-Project/parallel_write',
     }
 
 html_use_smartypants = True
